#' @importFrom rxode2 rxModelVars
#' @export
rxode2::rxModelVars

#' @importFrom rxode2 rxUiGet
#' @export
rxode2::rxUiGet

#' @importFrom nlmixr2est nlmixr2Est
#' @export
nlmixr2est::nlmixr2Est

#' @importFrom rxode2 .minfo
#' @export
rxode2::.minfo

#' @importFrom nlmixr2est nmObjGetFoceiControl
#' @export
nlmixr2est::nmObjGetFoceiControl

#' @importFrom nlmixr2est getValidNlmixrCtl
#' @export
nlmixr2est::getValidNlmixrCtl

#' @importFrom nlmixr2est nmObjHandleControlObject
#' @export
nlmixr2est::nmObjHandleControlObject

#' @importFrom nlmixr2est nmObjGetControl
#' @export
nlmixr2est::nmObjGetControl

#' @importFrom nonmem2rx nonmem2rx
#' @export
nonmem2rx::nonmem2rx

#' @importFrom nonmem2rx nmcov
#' @export
nonmem2rx::nmcov

#' @importFrom nonmem2rx nmext
#' @export
nonmem2rx::nmext

#' @importFrom nonmem2rx nminfo
#' @export
nonmem2rx::nminfo

#' @importFrom nonmem2rx nmtab
#' @export
nonmem2rx::nmtab

#' @importFrom nonmem2rx nmxml
#' @export
nonmem2rx::nmxml

#' @importFrom nonmem2rx as.nonmem2rx
#' @export
nonmem2rx::as.nonmem2rx

#' @importFrom monolix2rx monolix2rx
#' @export
monolix2rx::monolix2rx

#' @importFrom monolix2rx mlxtran
#' @export
monolix2rx::mlxtran
